@@ -28,7 +28,7 @@ class Activity():
             ))
 
         self.properties[0].value = (
-            self.post.date + " SYR " + self.orientation + ' ' +
+            self.post.short_date + " SYR " + self.orientation + ' ' +
             self.verb + ' IVO ' + self.location
         )
 
