@@ -178,17 +178,17 @@ class Property():
         if self.name == 'Source Text':
             self.value = (
                 'Syrian Observatory for Human Rights Facebook Page ' +
-                self.post.date
+                str(self.post.short_date)
             )
 
         if self.name == 'Country Team':
             self.value = 'MESP-Syria'
 
         if self.name == 'Date Begin':
-            self.value = self.post.formatted_date
+            self.value = self.post.short_date
 
         if self.name == 'Date End':
-            self.value = self.post.formatted_date
+            self.value = self.post.short_date
 
     def check(self, value):
         while True:
